..
    CredentialManager documentation master file, created by
    sphinx-quickstart on Sun Apr 19 14:02:09 2020.
    You can adapt this file completely to your liking, but it should at least
    contain the root `toctree` directive.

Welcome to Credmgr's documentation!
===================================

.. _gettingstarted:

.. toctree::
    :maxdepth: 1
    :caption: Getting Started

    getting_started/installation
    getting_started/quick_start
    getting_started/authentication
    getting_started/configuration
    getting_started/multiple_instances
    getting_started/logging

.. _codeoverview:

.. toctree::
    :maxdepth: 1
    :caption: Client Overview

    client_overview/credmgr_instance
    client_overview/credmgr_models
    client_overview/exceptions
    client_overview/other

.. _examples:

.. toctree::
    :maxdepth: 1
    :caption: Examples

    examples/reddit_bot.rst

.. _index:

.. toctree::
    :maxdepth: 1

    genindex

- :ref:`modindex`
- :ref:`search`
